# Changelog

All notable changes to this project will be documented in this file.

## [0.8.1] - 2025-03-28

### Bug Fixes

- Pydantic 2.11.0 compatibility (hotfix) (#106)

## [0.8.0] - 2025-03-27

### Features

- Implement check_gradients runtime command (#72)
- [**breaking**] Validate endpoint argument names before building (#95)

### Bug Fixes

- OpenAPI schema failure for differentiable arrays with unknown shape (#100)
- Prevent silent conversion of float array to int (#96)
- Use fixed uid/gid 5000:5000 for all tesseracts (#102)
- Use uid 1000 instead of 5000 (#104)

### Refactor

- Unpack endpoint payload (#80)

### Documentation

- Dependencies and user privileges (#91)

## [0.7.4] - 2025-03-20

### Features

- Friendlier error messages when input validation fails (#71)
- Pytorch initialize template (#53)
- Add `diffable` field to input/output json schemas (#82)
- Add stdout output for tesseract build (#87)

### Documentation

- Various docs nits + UX fixes (#85)

## [0.7.3] - 2025-03-13

### Features

- Raise proper error (`ValidationError`) for invalid inputs (#67)
- Add `abstract_eval` method to `tesseract_core.Tesseract` (#76)

### Bug Fixes

- Jax template now uses equinox `filter_jit` to allow non-array inputs (#56)
- Added pip as dependency (#58)
- Issue #74 (#75)

### Documentation

- Updated comments in jax recipe and docs on Differentiable flag (#65)

## [0.7.2] - 2025-02-27

### Bug Fixes

- Validate ShapeDType in abstract-eval schemas (#40)
- Resolve paths before passing volumes to docker (#48)
- Dangling Tesseracts in e2e tests (#51)
- Sanitize error output (#52)

### Documentation

- Python API for Julia example (#37)
- Fix links again (#49)

## [0.7.1] - 2025-02-26

### Bug Fixes

- Address issues in installing and first steps with Tesseract (#30)

## [0.7.0] - 2025-02-25

### Refactor

- Remove LocalClient and use HTTPClient for local Tesseracts as well (#27)

### Documentation

- Python API for PyTorch example (#24)
- Fix RBF fitting example (#25)

<!-- generated by git-cliff -->
